@@ -9,15 +9,17 @@ import numpy as np
 import pandas as pd
 import woodwork as ww
 
-from evalml.automl.utils import tune_binary_threshold
+from evalml.automl.utils import (
+    get_threshold_tuning_info,
+    resplit_training_data,
+    tune_binary_threshold,
+)
 from evalml.exceptions import PipelineScoreError
-from evalml.preprocessing import split_data
 from evalml.problem_types import (
     ProblemTypes,
     handle_problem_types,
     is_binary,
     is_classification,
-    is_time_series,
 )
 
 
@@ -147,30 +149,16 @@ def train_pipeline(pipeline, X, y, automl_config, schema=True, get_hashes=False)
         X.ww.init(schema=automl_config.X_schema)
     if automl_config.y_schema and schema:
         y.ww.init(schema=automl_config.y_schema)
-    threshold_tuning_objective = automl_config.objective
-    if (
-        is_binary(automl_config.problem_type)
-        and automl_config.optimize_thresholds
-        and automl_config.objective.score_needs_proba
-        and automl_config.alternate_thresholding_objective is not None
-    ):
-        # use the alternate_thresholding_objective
-        threshold_tuning_objective = automl_config.alternate_thresholding_objective
-    if (
-        automl_config.optimize_thresholds
-        and pipeline.can_tune_threshold_with_objective(threshold_tuning_objective)
-    ):
-        test_size_ = (
-            pipeline.forecast_horizon / len(X)
-            if is_time_series(automl_config.problem_type)
-            else 0.2
-        )
-        X, X_threshold_tuning, y, y_threshold_tuning = split_data(
+    (
+        threshold_tuning_objective,
+        data_needs_resplitting,
+    ) = get_threshold_tuning_info(automl_config, pipeline)
+
+    if data_needs_resplitting:
+        X, X_threshold_tuning, y, y_threshold_tuning = resplit_training_data(
+            pipeline,
             X,
             y,
-            pipeline.problem_type,
-            test_size=test_size_,
-            random_seed=pipeline.random_seed,
         )
     cv_pipeline = pipeline.clone()
     cv_pipeline.fit(X, y)
