@@ -1,5 +1,4 @@
 import string
-import warnings
 from unittest.mock import patch
 
 import numpy as np
@@ -99,33 +98,6 @@ def test_xgboost_predict_all_boolean_columns():
     assert not preds.isna().any()
 
 
-@pytest.mark.xfail
-@pytest.mark.parametrize(
-    "y,label_encoder",
-    [
-        ([True, False, False], True),
-        ([1.0, 1.1, 1.1], True),
-        (["One", "Two", "Two"], True),
-        ([0, 1, 1], False),
-    ],
-)
-def test_xgboost_catch_warnings_label_encoder(y, label_encoder):
-    X = pd.DataFrame({"a": [True, False, True], "b": [True, False, True]})
-    y = pd.Series(y)
-    xgb = XGBoostClassifier()
-    with warnings.catch_warnings(record=True) as w:
-        warnings.simplefilter("always")
-        xgb.fit(X, y)
-    assert len(w) == 0
-    preds = xgb.predict(X)
-    # make sure the predicted outputs are the same labels as the passed-in labels
-    assert preds[0] in y.values
-    if label_encoder:
-        assert xgb._label_encoder is not None
-        return
-    assert xgb._label_encoder is None
-
-
 @patch("xgboost.XGBClassifier.fit")
 @patch("xgboost.XGBClassifier.predict")
 @patch("xgboost.XGBClassifier.predict_proba")
