@@ -13,6 +13,7 @@ from sklearn import datasets
 from sklearn.preprocessing import minmax_scale
 from skopt.space import Integer, Real
 from woodwork import logical_types as ww_logical_types
+from woodwork.logical_types import Ordinal
 
 from evalml.demos import load_weather
 from evalml.model_family import ModelFamily
@@ -845,6 +846,19 @@ def X_y_categorical_regression():
     return X, y
 
 
+@pytest.fixture
+def X_y_ordinal_regression(X_y_categorical_regression):
+    X, y = X_y_categorical_regression
+    X = X.ww.copy()
+    y = y.ww.copy()
+    X.ww.set_types(
+        logical_types={
+            "day": Ordinal(order=["Sun", "Mon", "Tue", "Wed", "Thur", "Fri", "Sat"]),
+        },
+    )
+    return X, y
+
+
 @pytest.fixture
 def X_y_categorical_classification():
     data_path = os.path.join(os.path.dirname(__file__), "data/titanic.csv")
